summaryrefslogtreecommitdiff
path: root/libopenjpeg/image.h
diff options
context:
space:
mode:
authorMickael Savinaud <savmickael@users.noreply.github.com>2011-09-19 13:30:21 +0000
committerMickael Savinaud <savmickael@users.noreply.github.com>2011-09-19 13:30:21 +0000
commitb0ef524b9e0e0b84c97ead25ee84531b7ada35ec (patch)
tree530d72cfc326f5e48afac7a2fd92c831478ddf9b /libopenjpeg/image.h
parentb138aaae08d81965d0451465426d057aed3cbbfc (diff)
WIP: new image_header struct is used and enable used of cstr_info
Diffstat (limited to 'libopenjpeg/image.h')
-rw-r--r--libopenjpeg/image.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/libopenjpeg/image.h b/libopenjpeg/image.h
index cb6ad650..5be33b35 100644
--- a/libopenjpeg/image.h
+++ b/libopenjpeg/image.h
@@ -46,12 +46,19 @@ Create an empty image
opj_image_t* opj_image_create0(void);
/**
- * Updates the components of the image from the coding parameters.
+Create an empty image header
+@return returns an image header if successful, returns NULL otherwise
+*/
+opj_image_header_t* opj_image_header_create0(void);
+
+
+/**
+ * Updates the components characteristics of the image from the coding parameters.
*
* @param p_image the image to update.
* @param p_cp the coding parameters from which to update the image.
*/
-void opj_image_comp_update(struct opj_image * p_image,const struct opj_cp_v2 * p_cp);
+void opj_image_comp_header_update(struct opj_image_header * p_image_header, const struct opj_cp_v2* p_cp);
/*@}*/
@@ -46,12 +46,19 @@ Create an empty image
*
- * @param p_image the image to update.
+ * @param p_image_header the image header to update.
* @param p_cp the coding parameters from which to update the image.
*/